# -*- coding: utf-8 -*-

__author__ = 'Carlos Damázio'
__email__ = 'carlos.damazio@damazio.dev'
__version__ = '1.2.0'


from .python_aisweb import AISWEB

__all__ = [
    'AISWEB'
]
